@@ -359,14 +359,7 @@ MakefileGenerator::generateDependencies(TQPtrList<MakefileDependDir> &dirs, cons
 		x++;
 	    if(*(big_buffer + x) == '<') {
 		x++;
-		if(total_size_read >= x + 12 && !strncmp(big_buffer + x, "includehint", 11) &&
-		    (*(big_buffer + x + 11) == ' ' || *(big_buffer + x + 11) == '>')) {
-		    for(x += 11; *(big_buffer + x) != '>'; x++);
-		    int inc_len = 0;
-		    for(x += 1 ; *(big_buffer + x + inc_len) != '<'; inc_len++);
-		    *(big_buffer + x + inc_len) = '\0';
-		    inc = big_buffer + x;
-		} else if(total_size_read >= x + 13 && !strncmp(big_buffer + x, "customwidget", 12) &&
+		if(total_size_read >= x + 13 && !strncmp(big_buffer + x, "customwidget", 12) &&
 			  (*(big_buffer + x + 12) == ' ' || *(big_buffer + x + 12) == '>')) {
 		    for(x += 13; *(big_buffer + x) != '>'; x++); //skip up to >
 		    while(x < total_size_read) {
