@@ -287,14 +287,14 @@ class Q_EXPORT TQStyleControlElementData {
 		TQ_UINT32 topLevelWidgetFlags;
 		TQPixmap paletteBgPixmap;
 
-#ifdef ENABLE_QSTYLECONTROLELEMENTDATA_SLOW_COPY
+#ifdef ENABLE_TQSTYLECONTROLELEMENTDATA_SLOW_COPY
 	public:
 		TQStyleControlElementData(const TQStyleControlElementData&);
-#else // ENABLE_QSTYLECONTROLELEMENTDATA_SLOW_COPY
+#else
 	private:
 		// Disable copy constructor
 		TQStyleControlElementData(const TQStyleControlElementData&);
-#endif // ENABLE_QSTYLECONTROLELEMENTDATA_SLOW_COPY
+#endif
 
 };
 
