@@ -1399,7 +1399,7 @@ void TQSGIStyle::drawComplexControl( ComplexControl control,
 	break;
 
     default:
-// 	TQMotifStyle::drawComplexControl( control, p, ceData, elementFlags, r, cg, flags, sub, subActive, opt, widget );
+ 	TQMotifStyle::drawComplexControl( control, p, ceData, elementFlags, r, cg, flags, sub, subActive, opt, widget );
 	break;
     }
 }
